@@ -91,7 +91,6 @@ class BaseFactorModel(pl.LightningModule):
         self._result: Optional[BaseResult] = None
         self.training_state: Optional[Any] = None
         self._data_module: Optional[Any] = None
-        self._nowcast: Optional[Any] = None
     
     @property
     def config(self) -> DFMConfig:
@@ -494,48 +493,10 @@ class BaseFactorModel(pl.LightningModule):
         self._config = None
         self._data_module = None
         self._result = None
-        self._nowcast = None
         if hasattr(self, 'training_state'):
             self.training_state = None
         return self
     
-    def plot(self, **kwargs) -> 'BaseFactorModel':
-        """Plot common visualizations (not yet implemented).
-        
-        .. note::
-            This method is a placeholder for future visualization features.
-            For now, use external plotting libraries (matplotlib, plotly) with
-            model results: ``result = model.get_result()`` then plot ``result.Z``
-            (factors) or ``result.X_sm`` (smoothed data).
-        
-        Parameters
-        ----------
-        **kwargs
-            Additional keyword arguments (reserved for future use)
-            
-        Returns
-        -------
-        BaseFactorModel
-            Self for method chaining
-            
-        Raises
-        ------
-        ValueError
-            If model has not been trained yet
-        """
-        if self.training_state is None:
-            error_msg = self._format_error_message(
-                operation="plotting",
-                reason="model has not been trained yet",
-                guidance="Please call trainer.fit(model, data_module) first"
-            )
-            raise ValueError(error_msg)
-        _logger.warning(
-            "Plot functionality not yet implemented. Use external plotting libraries "
-            "with model results: result = model.get_result(); plot(result.Z)"
-        )
-        return self
-    
     def load_pickle(self, path: Union[str, Path], **kwargs) -> 'BaseFactorModel':
         """Load a saved model from pickle file.
         
